==> breadcrumb-9.1.61.tgz: package/README.md <==
# Smart.Breadcrumb for Angular is part of the jQWidgets Smart UI Components Library for Angular.
 Smart.Breadcrumb represents a feature-complete, responsive and touch friendly Angular Breadcrumb component. 
 > This is a commercial product and requires a paid license for use. You can purchase a license at https://www.jqwidgets.com/license/ or start a free 30-day trial.
> 
 ## Resources
 * [Getting Started](https://www.htmlelements.com/docs/angular-cli/)
* [View Online Demos](https://www.htmlelements.com/angular/)

 ## Highlights
 ### Enterprise features for Angular
 The Smart UI for Angular library includes accessibility features(WAI-ARIA, Section 508), Localization, RTL, Keyboard Navigation.
 ### Modular architecture
 All components are built as modules so only the components and features you need are imported in your application.
 ### Blazing Fast
 All components are built from scratch in order to achieve the best performance and user experience.
 ### Responsive, Touch & mobile friendly
 Our components come with built-in device and browser detection. A component automatically adjusts itself for optimal user experience.
 ## Showcase Applications
 * [Admin Template](https://www.htmlelements.com/demos/page-templates/admin-template/)
 * [Admin Template 2](https://www.htmlelements.com/demos/page-templates/admin-template-2/)
 * [Admin Template 3](https://www.htmlelements.com/demos/page-templates/admin-template-3/)
 ## Support
 Product support is available for through following mediums.
 * [Community forum](https://www.htmlelements.com/forums/).
 * New [GitHub issue](https://github.com/htmlelements/smart-webcomponents/issues/new).
 * Support e-mail: support@jqwidgets.com
 ## Usage
 * Download and install the package
 ```javascript
npm install @smart-webcomponents-angular/breadcrumb
 ```
 * Adding CSS reference
 
The CSS files are available in ../node_modules/@smart-webcomponents-angular/breadcrumb/styles/ folder.
```javascript
"styles": [
	"node_modules/@smart-webcomponents-angular/breadcrumb/styles/smart.breadcrumb.css"
]
```
 * Add the Component Module in your application

```typescript
import { NgModule } from '@angular/core';
import { BrowserModule } from '@angular/platform-browser';

import { BreadcrumbModule } from '@smart-webcomponents-angular/breadcrumb';

import { AppComponent } from './app.component';

@NgModule({
    declarations: [ AppComponent ],
    imports: [ BrowserModule, BreadcrumbModule ],
    bootstrap: [ AppComponent ],
	entryComponents: [ AppComponent ]
})

export class AppModule { }
``` 
 
 
 ## License
 Check the license detail [here](https://jqwidgets.com/license/).
 ## Release Notes
 Check the release notes [here](https://www.htmlelements.com/docs/release-notes/)
     © Copyright 2021 jQWidgets, Ltd. All Rights Reserved.

==> breadcrumb-13.0.9.tgz: package/README.md <==
# Smart.Breadcrumb for Angular is part of the jQWidgets Smart UI Components Library for Angular.
 Smart.Breadcrumb represents a feature-complete, responsive and touch friendly Angular Breadcrumb component. 
 > This is a commercial product and requires a paid license for use. You can purchase a license at https://www.jqwidgets.com/license/ or start a free 30-day trial.
> 
 ## Angular 13 support
 
 The Smart UI for Angular components are packaged using the latest Angular Package Format guidelines. 
 
 ## Resources
 * [Getting Started](https://www.htmlelements.com/docs/angular-cli/)
* [View Online Demos](https://www.htmlelements.com/angular/)

 ## Highlights
 ### Enterprise features for Angular
 The Smart UI for Angular library includes accessibility features(WAI-ARIA, Section 508), Localization, RTL, Keyboard Navigation.
 ### Modular architecture
 All components are built as modules so only the components and features you need are imported in your application.
 ### Blazing Fast
 All components are built from scratch in order to achieve the best performance and user experience.
 ### Responsive, Touch & mobile friendly
 Our components come with built-in device and browser detection. A component automatically adjusts itself for optimal user experience.
 ## Showcase Applications
 * [Admin Template](https://www.htmlelements.com/demos/page-templates/admin-template/)
 * [Admin Template 2](https://www.htmlelements.com/demos/page-templates/admin-template-2/)
 * [Admin Template 3](https://www.htmlelements.com/demos/page-templates/admin-template-3/)
 ## Support
 Product support is available for through following mediums.
 * [Community forum](https://www.htmlelements.com/forums/).
 * New [GitHub issue](https://github.com/htmlelements/smart-webcomponents/issues/new).
 * Support e-mail: support@jqwidgets.com
 ## Usage
 * Download and install the package
 ```javascript
npm install @smart-webcomponents-angular/breadcrumb
 ```
 * Adding CSS reference
 
The CSS files are available in ../node_modules/@smart-webcomponents-angular/breadcrumb/styles/ folder.
```javascript
"styles": [
	"node_modules/@smart-webcomponents-angular/breadcrumb/styles/smart.base.css",
	"node_modules/@smart-webcomponents-angular/breadcrumb/styles/smart.breadcrumb.css",
	"node_modules/@smart-webcomponents-angular/breadcrumb/styles/smart.common.css"
]

If you use more than one Smart UI component in your application, firstly add 'smart.base.css', then your components css files like 'smart.grid.css', 'smart.scheduler.css' and finally 'smart.common.css'. 
```
 * Add the Component Module in your application

```typescript
import { NgModule } from '@angular/core';
import { BrowserModule } from '@angular/platform-browser';

import { BreadcrumbModule } from '@smart-webcomponents-angular/breadcrumb';

import { AppComponent } from './app.component';

@NgModule({
    declarations: [ AppComponent ],
    imports: [ BrowserModule, BreadcrumbModule ],
    bootstrap: [ AppComponent ],
	entryComponents: [ AppComponent ]
})

export class AppModule { }
``` 
 
 
 ## License
 Check the license detail [here](https://jqwidgets.com/license/).
 ## Release Notes
 Check the release notes [here](https://www.htmlelements.com/docs/release-notes/)
     © Copyright 2022 jQWidgets, Ltd. All Rights Reserved.
